@@ -1,25 +1,25 @@
-# -*- coding: utf-8 -*-
-from __future__ import unicode_literals
-
 from django.core.exceptions import ValidationError
 from django.core.management.base import BaseCommand, CommandError
 from django.core.validators import validate_ipv46_address
+
 from ... import models
 
 
 class Command(BaseCommand):
-    help = 'Adds an IP address to an IP Group.'
+    help = "Adds an IP address to an IP Group."
 
     def add_arguments(self, parser):
-        parser.add_argument('group_name')
-        parser.add_argument('ip', nargs='+')
+        parser.add_argument("group_name")
+        parser.add_argument("ip", nargs="+")
 
     def handle(self, *args, **options):
-        group_name = options.get('group_name')
-        ips = options.get('ip')
+        group_name = options.get("group_name")
+        ips = options.get("ip")
 
         try:
-            ip_group = models.IPGroup.objects.get(name__iexact=group_name, type=models.TYPE_RANGE)
+            ip_group = models.IPGroup.objects.get(
+                name__iexact=group_name, type=models.TYPE_RANGE
+            )
         except models.IPGroup.DoesNotExist:
             try:
                 models.IPGroup.objects.get(name__iexact=group_name)
