@@ -7,17 +7,17 @@ from django.db import migrations, models
 class Migration(migrations.Migration):
 
     dependencies = [
-        ('iprestrict', '0004_add_iplocation'),
+        ("iprestrict", "0004_add_iplocation"),
     ]
 
     operations = [
         migrations.AlterModelOptions(
-            name='ipgroup',
-            options={'verbose_name': 'IP Group'},
+            name="ipgroup",
+            options={"verbose_name": "IP Group"},
         ),
         migrations.AddField(
-            model_name='rule',
-            name='reverse_ip_group',
+            model_name="rule",
+            name="reverse_ip_group",
             field=models.BooleanField(default=False),
         ),
     ]
