@@ -1,10 +1,7 @@
-# -*- coding: utf-8 -*-
-from __future__ import unicode_literals
-
 from django.utils import timezone
 
 
-class IPRestrictor(object):
+class IPRestrictor:
     rules = None
     last_reload = None
 
@@ -20,6 +17,7 @@ class IPRestrictor(object):
     def load_rules(self):
         # We are caching the rules, to avoid DB lookup on each request
         from .models import Rule
+
         self.rules = list(Rule.objects.all())
         self.last_reload = timezone.now()
 
